@@ -16,8 +16,6 @@ import collections
 import re
 import sys
 
-import six
-
 from yaql.language import exceptions
 from yaql.language import lexer
 
@@ -28,54 +26,58 @@ def create_marker(msg):
             return msg
     return MarkerClass()
 
+
 KEYWORD_REGEX = re.compile(lexer.Lexer.t_KEYWORD_STRING.__doc__.strip())
 NO_VALUE = create_marker('<NoValue>')
 
 
 def is_iterator(obj):
-    return isinstance(obj, collections.Iterator)
+    return isinstance(obj, collections.abc.Iterator)
 
 
 def is_iterable(obj):
-    return isinstance(obj, collections.Iterable) and not isinstance(
-        obj, six.string_types + (MappingType,))
+    return (
+        isinstance(obj, collections.abc.Iterable) and
+        not isinstance(obj, (str, MappingType))
+    )
 
 
 def is_sequence(obj):
-    return isinstance(obj, collections.Sequence) and not isinstance(
-        obj, six.string_types)
+    return isinstance(obj, collections.abc.Sequence) and not isinstance(
+        obj, str)
 
 
 def is_mutable(obj):
-    return isinstance(obj, (collections.MutableSequence,
-                            collections.MutableSet,
-                            collections.MutableMapping))
+    return isinstance(obj, (collections.abc.MutableSequence,
+                            collections.abc.MutableSet,
+                            collections.abc.MutableMapping))
 
-SequenceType = collections.Sequence
-MutableSequenceType = collections.MutableSequence
-SetType = collections.Set
-MutableSetType = collections.MutableSet
-MappingType = collections.Mapping
-MutableMappingType = collections.MutableMapping
-IterableType = collections.Iterable
-IteratorType = collections.Iterator
+
+SequenceType = collections.abc.Sequence
+MutableSequenceType = collections.abc.MutableSequence
+SetType = collections.abc.Set
+MutableSetType = collections.abc.MutableSet
+MappingType = collections.abc.Mapping
+MutableMappingType = collections.abc.MutableMapping
+IterableType = collections.abc.Iterable
+IteratorType = collections.abc.Iterator
 QueueType = collections.deque
 
 
 def convert_input_data(obj, rec=None):
     if rec is None:
         rec = convert_input_data
-    if isinstance(obj, six.string_types):
-        return obj if isinstance(obj, six.text_type) else six.text_type(obj)
+    if isinstance(obj, str):
+        return obj if isinstance(obj, str) else str(obj)
     elif isinstance(obj, SequenceType):
         return tuple(rec(t, rec) for t in obj)
     elif isinstance(obj, MappingType):
         return FrozenDict((rec(key, rec), rec(value, rec))
-                          for key, value in six.iteritems(obj))
+                          for key, value in obj.items())
     elif isinstance(obj, MutableSetType):
         return frozenset(rec(t, rec) for t in obj)
     elif isinstance(obj, IterableType):
-        return six.moves.map(lambda v: rec(v, rec), obj)
+        return map(lambda v: rec(v, rec), obj)
     else:
         return obj
 
@@ -83,9 +85,9 @@ def convert_input_data(obj, rec=None):
 def convert_output_data(obj, limit_func, engine, rec=None):
     if rec is None:
         rec = convert_output_data
-    if isinstance(obj, collections.Mapping):
+    if isinstance(obj, collections.abc.Mapping):
         result = {}
-        for key, value in limit_func(six.iteritems(obj)):
+        for key, value in limit_func(obj.items()):
             result[rec(key, limit_func, engine, rec)] = rec(
                 value, limit_func, engine, rec)
         return result
@@ -117,7 +119,7 @@ class MappingRule(object):
         self.destination = destination
 
 
-class FrozenDict(collections.Mapping):
+class FrozenDict(collections.abc.Mapping):
     def __init__(self, *args, **kwargs):
         self._d = dict(*args, **kwargs)
         self._hash = None
@@ -137,7 +139,7 @@ class FrozenDict(collections.Mapping):
     def __hash__(self):
         if self._hash is None:
             self._hash = 0
-            for pair in six.iteritems(self):
+            for pair in self.items():
                 self._hash ^= hash(pair)
         return self._hash
 
@@ -151,7 +153,7 @@ def memorize(collection, engine):
 
     yielded = []
 
-    class RememberingIterator(six.Iterator):
+    class RememberingIterator:
         def __init__(self):
             self.seq = iter(collection)
             self.index = 0
