@@ -63,9 +63,9 @@ class TestQueries(yaql.tests.TestCase):
 
     def test_distinct_with_selector(self):
         data = [['a', 1], ['b', 2], ['c', 1], ['d', 3], ['e', 2]]
-        self.assertItemsEqual([['a', 1], ['b', 2], ['d', 3]],
+        self.assertCountEqual([['a', 1], ['b', 2], ['d', 3]],
                               self.eval('$.distinct($[1])', data=data))
-        self.assertItemsEqual([['a', 1], ['b', 2], ['d', 3]],
+        self.assertCountEqual([['a', 1], ['b', 2], ['d', 3]],
                               self.eval('distinct($, $[1])', data=data))
 
     def test_any(self):
@@ -115,7 +115,7 @@ class TestQueries(yaql.tests.TestCase):
         self.assertEqual(100, self.eval('[].sum(100)'))
 
     def test_memorize(self):
-        generator_func = lambda: (i for i in range(3))
+        generator_func = lambda: (i for i in range(3))  # noqa: E731
         self.assertRaises(
             TypeError,
             self.eval, '$.len() + $.sum()', data=generator_func())
@@ -196,7 +196,7 @@ class TestQueries(yaql.tests.TestCase):
 
     def test_group_by(self):
         data = {'a': 1, 'b': 2, 'c': 1, 'd': 3, 'e': 2}
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [
                 [1, [['a', 1], ['c', 1]]],
                 [2, [['b', 2], ['e', 2]]],
@@ -204,28 +204,52 @@ class TestQueries(yaql.tests.TestCase):
             ],
             self.eval('$.items().orderBy($[0]).groupBy($[1])', data=data))
 
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [[1, ['a', 'c']], [2, ['b', 'e']], [3, ['d']]],
             self.eval('$.items().orderBy($[0]).groupBy($[1], $[0])',
                       data=data))
 
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [[1, 'ac'], [2, 'be'], [3, 'd']],
             self.eval('$.items().orderBy($[0]).'
                       'groupBy($[1], $[0], $.sum())', data=data))
 
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
             self.eval('$.items().orderBy($[0]).'
                       'groupBy($[1],,  $.sum())',
                       data=data))
 
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
             self.eval('$.items().orderBy($[0]).'
                       'groupBy($[1], aggregator => $.sum())',
                       data=data))
 
+    def test_group_by_old_syntax(self):
+        # Test the syntax used in 1.1.1 and earlier, where the aggregator
+        # function was passed the key as well as the value list, and returned
+        # the key along with the aggregated value. This ensures backward
+        # compatibility with existing expressions.
+        data = {'a': 1, 'b': 2, 'c': 1, 'd': 3, 'e': 2}
+
+        self.assertCountEqual(
+            [[1, 'ac'], [2, 'be'], [3, 'd']],
+            self.eval('$.items().orderBy($[0]).'
+                      'groupBy($[1], $[0], [$[0], $[1].sum()])', data=data))
+
+        self.assertCountEqual(
+            [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
+            self.eval('$.items().orderBy($[0]).'
+                      'groupBy($[1],,  [$[0], $[1].sum()])',
+                      data=data))
+
+        self.assertCountEqual(
+            [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
+            self.eval('$.items().orderBy($[0]).'
+                      'groupBy($[1], aggregator => [$[0], $[1].sum()])',
+                      data=data))
+
     def test_join(self):
         self.assertEqual(
             [[2, 1], [3, 1], [3, 2], [4, 1], [4, 2], [4, 3]],
